spacepy.plot.spectrogram — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- plot - Plot, various specialized plotting functions and associated utilities »

# spacepy.plot.spectrogram

Create and plot generic ‘spectrograms’ for space science. This is not a signal processing routine and does not apply Fourier transforms (or similar) to the data. The functionality provided here is the binning (and averaging) of multi-dimensional to provide a 2D output map of some quantity as a function of two parameters. An example would be particle data from a satellite mission: electron flux, at a given energy, can be binned as a function of both time and McIlwain L, then plotted as a 2D color-map, colloquially known as a spectrogram.

In many other settings ‘spectrogram’ refers to a transform of data from the time domain to the frequency domain, and the subsequent plotting of some quantity (e.g., power spectral density) as a function of time and frequency. To approximate this functionality for, e.g., time-series magnetic field data you would first calculate a the power spectral density and then use `spectrogram` to rebin the data for visualaization.

Authors: Brian Larsen and Steve Morley Institution: Los Alamos National Laboratory Contact: balarsen@lanl.gov, smorley@lanl.gov Los Alamos National Laboratory

Copyright 2011 Los Alamos National Security, LLC.

`spectrogram`(data, **kwargs) | This class rebins data to produce a 2D data map that can be plotted as a spectrogram

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- plot - Plot, various specialized plotting functions and associated utilities »